summaryrefslogtreecommitdiffstats
path: root/image.py
diff options
context:
space:
mode:
authorChris Lumens <clumens@redhat.com>2008-05-06 15:27:39 -0400
committerChris Lumens <clumens@redhat.com>2008-05-06 15:28:46 -0400
commit6bdccf0c88dfff3c41c02b8d3080f6988fbc960f (patch)
treea001a95f57292b974e1b095ed3760801dd03f23c /image.py
parentfd2106db246bb7bf0c86b822ca57ca4683ce13b6 (diff)
downloadanaconda-6bdccf0c88dfff3c41c02b8d3080f6988fbc960f.tar.gz
anaconda-6bdccf0c88dfff3c41c02b8d3080f6988fbc960f.tar.xz
anaconda-6bdccf0c88dfff3c41c02b8d3080f6988fbc960f.zip
Look in the right place when ISO images are in a subdirectory (#443580).
Diffstat (limited to 'image.py')
-rw-r--r--image.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/image.py b/image.py
index 5fece2314..681cf9825 100644
--- a/image.py
+++ b/image.py
@@ -129,8 +129,8 @@ def getMediaId(path):
return None
# This mounts the directory containing the iso images, and places the
-# mount point in isodir.
-def mountDirectory(isodir, methodstr, messageWindow):
+# mount point in /mnt/isodir.
+def mountDirectory(methodstr, messageWindow):
if methodstr.startswith("hd:"):
method = methodstr[3:]
(device, fstype, path) = method.split(":", 3)
@@ -153,7 +153,7 @@ def mountDirectory(isodir, methodstr, messageWindow):
return
try:
- isys.mount(device, isodir, fstype = fstype)
+ isys.mount(device, "/mnt/isodir", fstype = fstype)
except SystemError, msg:
log.error("couldn't mount ISO source directory: %s" % msg)
messageWindow(_("Couldn't Mount ISO Source"),